@@ -24,7 +24,7 @@ class EqlClient(NamespacedClient):
         """
         Returns results matching a query expressed in Event Query Language (EQL)
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/eql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/eql-search-api.html>`_
 
         :arg index: The name of the index to scope the operation
         :arg body: Eql request body. Use the `query` to limit the query
@@ -55,7 +55,7 @@ class EqlClient(NamespacedClient):
         Deletes an async EQL search by ID. If the search is still running, the search
         request will be cancelled. Otherwise, the saved search results are deleted.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/eql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/eql-search-api.html>`_
 
         :arg id: The async search ID
         """
@@ -72,7 +72,7 @@ class EqlClient(NamespacedClient):
         Returns async results from previously executed Event Query Language (EQL)
         search
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/eql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/eql-search-api.html>`_
 
         :arg id: The async search ID
         :arg keep_alive: Update the time interval in which the results
@@ -93,7 +93,7 @@ class EqlClient(NamespacedClient):
         Returns the status of a previously submitted async or stored Event Query
         Language (EQL) search
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/eql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/eql-search-api.html>`_
 
         :arg id: The async search ID
         """
