@@ -19,17 +19,19 @@ from .utils import SKIP_IN_PATH, NamespacedClient, _make_path, query_params
 
 
 class IngestClient(NamespacedClient):
-    @query_params("master_timeout")
+    @query_params("master_timeout", "summary")
     async def get_pipeline(self, id=None, params=None, headers=None):
         """
         Returns a pipeline.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/get-pipeline-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/get-pipeline-api.html>`_
 
         :arg id: Comma separated list of pipeline ids. Wildcards
             supported
         :arg master_timeout: Explicit operation timeout for connection
             to master node
+        :arg summary: Return pipelines without their definitions
+            (default: false)
         """
         return await self.transport.perform_request(
             "GET", _make_path("_ingest", "pipeline", id), params=params, headers=headers
@@ -40,7 +42,7 @@ class IngestClient(NamespacedClient):
         """
         Creates or updates a pipeline.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/put-pipeline-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/put-pipeline-api.html>`_
 
         :arg id: Pipeline ID
         :arg body: The ingest definition
@@ -65,7 +67,7 @@ class IngestClient(NamespacedClient):
         """
         Deletes a pipeline.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/delete-pipeline-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/delete-pipeline-api.html>`_
 
         :arg id: Pipeline ID
         :arg master_timeout: Explicit operation timeout for connection
@@ -87,7 +89,7 @@ class IngestClient(NamespacedClient):
         """
         Allows to simulate a pipeline with example documents.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/simulate-pipeline-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/simulate-pipeline-api.html>`_
 
         :arg body: The simulate definition
         :arg id: Pipeline ID
@@ -110,8 +112,19 @@ class IngestClient(NamespacedClient):
         """
         Returns a list of the built-in patterns.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/grok-processor.html#grok-processor-rest-get>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/grok-processor.html#grok-processor-rest-get>`_
         """
         return await self.transport.perform_request(
             "GET", "/_ingest/processor/grok", params=params, headers=headers
         )
+
+    @query_params()
+    async def geo_ip_stats(self, params=None, headers=None):
+        """
+        Returns statistical information about geoip databases
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/geoip-stats-api.html>`_
+        """
+        return await self.transport.perform_request(
+            "GET", "/_ingest/geoip/stats", params=params, headers=headers
+        )
