@@ -25,7 +25,7 @@ class MlClient(NamespacedClient):
         Closes one or more anomaly detection jobs. A job can be opened and closed
         multiple times throughout its lifecycle.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-close-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-close-job.html>`_
 
         :arg job_id: The name of the job to close
         :arg body: The URL params optionally sent in the body
@@ -55,7 +55,7 @@ class MlClient(NamespacedClient):
         """
         Deletes a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-calendar.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-delete-calendar.html>`_
 
         :arg calendar_id: The ID of the calendar to delete
         """
@@ -76,7 +76,7 @@ class MlClient(NamespacedClient):
         """
         Deletes scheduled events from a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-calendar-event.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-delete-calendar-event.html>`_
 
         :arg calendar_id: The ID of the calendar to modify
         :arg event_id: The ID of the event to remove from the calendar
@@ -97,7 +97,7 @@ class MlClient(NamespacedClient):
         """
         Deletes anomaly detection jobs from a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-calendar-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-delete-calendar-job.html>`_
 
         :arg calendar_id: The ID of the calendar to modify
         :arg job_id: The ID of the job to remove from the calendar
@@ -118,7 +118,7 @@ class MlClient(NamespacedClient):
         """
         Deletes an existing datafeed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-delete-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to delete
         :arg force: True if the datafeed should be forcefully deleted
@@ -140,7 +140,7 @@ class MlClient(NamespacedClient):
         """
         Deletes expired and unused machine learning data.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-expired-data.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-delete-expired-data.html>`_
 
         :arg body: deleting expired data parameters
         :arg job_id: The ID of the job(s) to perform expired data
@@ -163,7 +163,7 @@ class MlClient(NamespacedClient):
         """
         Deletes a filter.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-filter.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-delete-filter.html>`_
 
         :arg filter_id: The ID of the filter to delete
         """
@@ -182,7 +182,7 @@ class MlClient(NamespacedClient):
         """
         Deletes forecasts from a machine learning job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-forecast.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-delete-forecast.html>`_
 
         :arg job_id: The ID of the job from which to delete forecasts
         :arg forecast_id: The ID of the forecast to delete, can be comma
@@ -207,7 +207,7 @@ class MlClient(NamespacedClient):
         """
         Deletes an existing anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-delete-job.html>`_
 
         :arg job_id: The ID of the job to delete
         :arg force: True if the job should be forcefully deleted
@@ -229,7 +229,7 @@ class MlClient(NamespacedClient):
         """
         Deletes an existing model snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-delete-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-delete-snapshot.html>`_
 
         :arg job_id: The ID of the job to fetch
         :arg snapshot_id: The ID of the snapshot to delete
@@ -252,7 +252,7 @@ class MlClient(NamespacedClient):
         """
         Forces any buffered data to be processed by the job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-flush-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-flush-job.html>`_
 
         :arg job_id: The name of the job to flush
         :arg body: Flush parameters
@@ -283,7 +283,7 @@ class MlClient(NamespacedClient):
         """
         Predicts the future behavior of a time series by using its historical behavior.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-forecast.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-forecast.html>`_
 
         :arg job_id: The ID of the job to forecast for
         :arg duration: The duration of the forecast
@@ -317,7 +317,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves anomaly detection job results for one or more buckets.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-bucket.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-bucket.html>`_
 
         :arg job_id: ID of the job to get bucket results from
         :arg body: Bucket selection details if not provided in URI
@@ -355,7 +355,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves information about the scheduled events in calendars.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-calendar-event.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-calendar-event.html>`_
 
         :arg calendar_id: The ID of the calendar containing the events
         :arg end: Get events before this time
@@ -386,7 +386,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves configuration information for calendars.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-calendar.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-calendar.html>`_
 
         :arg body: The from and size parameters optionally sent in the
             body
@@ -413,7 +413,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves anomaly detection job results for one or more categories.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-category.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-category.html>`_
 
         :arg job_id: The name of the job
         :arg body: Category selection details if not provided in URI
@@ -447,7 +447,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves usage information for datafeeds.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-datafeed-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-datafeed-stats.html>`_
 
         :arg datafeed_id: The ID of the datafeeds stats to fetch
         :arg allow_no_datafeeds: Whether to ignore if a wildcard
@@ -469,7 +469,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves configuration information for datafeeds.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeeds to fetch
         :arg allow_no_datafeeds: Whether to ignore if a wildcard
@@ -493,7 +493,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves filters.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-filter.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-filter.html>`_
 
         :arg filter_id: The ID of the filter to fetch
         :arg from_: skips a number of filters
@@ -524,7 +524,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves anomaly detection job results for one or more influencers.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-influencer.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-influencer.html>`_
 
         :arg job_id: Identifier for the anomaly detection job
         :arg body: Influencer selection criteria
@@ -559,7 +559,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves usage information for anomaly detection jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-job-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-job-stats.html>`_
 
         :arg job_id: The ID of the jobs stats to fetch
         :arg allow_no_jobs: Whether to ignore if a wildcard expression
@@ -581,7 +581,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves configuration information for anomaly detection jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-job.html>`_
 
         :arg job_id: The ID of the jobs to fetch
         :arg allow_no_jobs: Whether to ignore if a wildcard expression
@@ -607,7 +607,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves information about model snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-snapshot.html>`_
 
         :arg job_id: The ID of the job to fetch
         :arg body: Model snapshot selection criteria
@@ -653,7 +653,7 @@ class MlClient(NamespacedClient):
         Retrieves overall bucket results that summarize the bucket results of multiple
         anomaly detection jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-overall-buckets.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-overall-buckets.html>`_
 
         :arg job_id: The job IDs for which to calculate overall bucket
             results
@@ -705,7 +705,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves anomaly records for an anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-get-record.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-get-record.html>`_
 
         :arg job_id: The ID of the job
         :arg body: Record selection criteria
@@ -739,7 +739,7 @@ class MlClient(NamespacedClient):
         """
         Returns defaults and limits used by machine learning.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/get-ml-info.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/get-ml-info.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_ml/info", params=params, headers=headers
@@ -750,7 +750,7 @@ class MlClient(NamespacedClient):
         """
         Opens one or more anomaly detection jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-open-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-open-job.html>`_
 
         :arg job_id: The ID of the job to open
         """
@@ -769,7 +769,7 @@ class MlClient(NamespacedClient):
         """
         Posts scheduled events in a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-post-calendar-event.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-post-calendar-event.html>`_
 
         :arg calendar_id: The ID of the calendar to modify
         :arg body: A list of events
@@ -791,7 +791,7 @@ class MlClient(NamespacedClient):
         """
         Sends data to an anomaly detection job for analysis.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-post-data.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-post-data.html>`_
 
         :arg job_id: The name of the job receiving the data
         :arg body: The data to process
@@ -814,24 +814,22 @@ class MlClient(NamespacedClient):
         )
 
     @query_params()
-    def preview_datafeed(self, datafeed_id, params=None, headers=None):
+    def preview_datafeed(self, body=None, datafeed_id=None, params=None, headers=None):
         """
         Previews a datafeed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-preview-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-preview-datafeed.html>`_
 
+        :arg body: The datafeed config and job config with which to
+            execute the preview
         :arg datafeed_id: The ID of the datafeed to preview
         """
-        if datafeed_id in SKIP_IN_PATH:
-            raise ValueError(
-                "Empty value passed for a required argument 'datafeed_id'."
-            )
-
         return self.transport.perform_request(
-            "GET",
+            "POST",
             _make_path("_ml", "datafeeds", datafeed_id, "_preview"),
             params=params,
             headers=headers,
+            body=body,
         )
 
     @query_params()
@@ -839,7 +837,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-put-calendar.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-put-calendar.html>`_
 
         :arg calendar_id: The ID of the calendar to create
         :arg body: The calendar details
@@ -862,7 +860,7 @@ class MlClient(NamespacedClient):
         """
         Adds an anomaly detection job to a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-put-calendar-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-put-calendar-job.html>`_
 
         :arg calendar_id: The ID of the calendar to modify
         :arg job_id: The ID of the job to add to the calendar
@@ -885,7 +883,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates a datafeed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-put-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-put-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to create
         :arg body: The datafeed config
@@ -916,7 +914,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates a filter.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-put-filter.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-put-filter.html>`_
 
         :arg filter_id: The ID of the filter to create
         :arg body: The filter details
@@ -938,7 +936,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates an anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-put-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-put-job.html>`_
 
         :arg job_id: The ID of the job to create
         :arg body: The job
@@ -962,7 +960,7 @@ class MlClient(NamespacedClient):
         """
         Reverts to a specific snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-revert-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-revert-snapshot.html>`_
 
         :arg job_id: The ID of the job to fetch
         :arg snapshot_id: The ID of the snapshot to revert to
@@ -995,7 +993,7 @@ class MlClient(NamespacedClient):
         Sets a cluster wide upgrade_mode setting that prepares machine learning indices
         for an upgrade.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-set-upgrade-mode.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-set-upgrade-mode.html>`_
 
         :arg enabled: Whether to enable upgrade_mode ML setting or not.
             Defaults to false.
@@ -1011,7 +1009,7 @@ class MlClient(NamespacedClient):
         """
         Starts one or more datafeeds.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-start-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-start-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to start
         :arg body: The start datafeed parameters
@@ -1039,7 +1037,7 @@ class MlClient(NamespacedClient):
         """
         Stops one or more datafeeds.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-stop-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-stop-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to stop
         :arg body: The URL params optionally sent in the body
@@ -1073,7 +1071,7 @@ class MlClient(NamespacedClient):
         """
         Updates certain properties of a datafeed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-update-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-update-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to update
         :arg body: The datafeed update settings
@@ -1104,7 +1102,7 @@ class MlClient(NamespacedClient):
         """
         Updates the description of a filter, adds items, or removes items.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-update-filter.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-update-filter.html>`_
 
         :arg filter_id: The ID of the filter to update
         :arg body: The filter update
@@ -1126,7 +1124,7 @@ class MlClient(NamespacedClient):
         """
         Updates certain properties of an anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-update-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-update-job.html>`_
 
         :arg job_id: The ID of the job to create
         :arg body: The job update settings
@@ -1150,7 +1148,7 @@ class MlClient(NamespacedClient):
         """
         Updates certain properties of a snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-update-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-update-snapshot.html>`_
 
         :arg job_id: The ID of the job to fetch
         :arg snapshot_id: The ID of the snapshot to update
@@ -1220,12 +1218,7 @@ class MlClient(NamespacedClient):
         """
         Deletes an existing data frame analytics job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/delete-dfanalytics.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/delete-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to delete
         :arg force: True if the job should be forcefully deleted
@@ -1247,12 +1240,7 @@ class MlClient(NamespacedClient):
         """
         Evaluates the data frame analytics for an annotated index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/evaluate-dfanalytics.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/evaluate-dfanalytics.html>`_
 
         :arg body: The evaluation definition
         """
@@ -1272,12 +1260,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves configuration information for data frame analytics jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/get-dfanalytics.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/get-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to fetch
         :arg allow_no_match: Whether to ignore if a wildcard expression
@@ -1305,12 +1288,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves usage information for data frame analytics jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/get-dfanalytics-stats.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/get-dfanalytics-stats.html>`_
 
         :arg id: The ID of the data frame analytics stats to fetch
         :arg allow_no_match: Whether to ignore if a wildcard expression
@@ -1337,12 +1315,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates a data frame analytics job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/put-dfanalytics.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/put-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to create
         :arg body: The data frame analytics configuration
@@ -1364,12 +1337,7 @@ class MlClient(NamespacedClient):
         """
         Starts a data frame analytics job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/start-dfanalytics.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/start-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to start
         :arg body: The start data frame analytics parameters
@@ -1392,12 +1360,7 @@ class MlClient(NamespacedClient):
         """
         Stops one or more data frame analytics jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/stop-dfanalytics.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/stop-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to stop
         :arg body: The stop data frame analytics parameters
@@ -1426,12 +1389,7 @@ class MlClient(NamespacedClient):
         Deletes an existing trained inference model that is currently not referenced by
         an ingest pipeline.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/delete-trained-models.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/delete-trained-models.html>`_
 
         :arg model_id: The ID of the trained model to delete
         """
@@ -1452,12 +1410,7 @@ class MlClient(NamespacedClient):
         """
         Explains a data frame analytics config.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/explain-dfanalytics.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/explain-dfanalytics.html>`_
 
         :arg body: The data frame analytics config to explain
         :arg id: The ID of the data frame analytics to explain
@@ -1484,12 +1437,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves configuration information for a trained inference model.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/get-trained-models.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/get-trained-models.html>`_
 
         :arg model_id: The ID of the trained models to fetch
         :arg allow_no_match: Whether to ignore if a wildcard expression
@@ -1528,12 +1476,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves usage information for trained inference models.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/get-trained-models-stats.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/get-trained-models-stats.html>`_
 
         :arg model_id: The ID of the trained models stats to fetch
         :arg allow_no_match: Whether to ignore if a wildcard expression
@@ -1559,12 +1502,7 @@ class MlClient(NamespacedClient):
         """
         Creates an inference trained model.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/put-trained-models.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/put-trained-models.html>`_
 
         :arg model_id: The ID of the trained models to store
         :arg body: The trained model configuration
@@ -1586,7 +1524,7 @@ class MlClient(NamespacedClient):
         """
         Estimates the model memory
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-apis.html>`_
 
         :arg body: The analysis config, plus cardinality estimates for
             fields it references
@@ -1607,12 +1545,7 @@ class MlClient(NamespacedClient):
         """
         Updates certain properties of a data frame analytics job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/update-dfanalytics.html>`_
-
-        .. warning::
-
-            This API is **beta** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/update-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to update
         :arg body: The data frame analytics settings to update
@@ -1634,7 +1567,7 @@ class MlClient(NamespacedClient):
         """
         Upgrades a given job snapshot to the current major version.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/ml-upgrade-job-model-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/ml-upgrade-job-model-snapshot.html>`_
 
         :arg job_id: The ID of the job
         :arg snapshot_id: The ID of the snapshot
@@ -1661,6 +1594,75 @@ class MlClient(NamespacedClient):
             headers=headers,
         )
 
+    @query_params()
+    def delete_trained_model_alias(
+        self, model_id, model_alias, params=None, headers=None
+    ):
+        """
+        Deletes a model alias that refers to the trained model
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/delete-trained-models-aliases.html>`_
+
+        :arg model_id: The trained model where the model alias is
+            assigned
+        :arg model_alias: The trained model alias to delete
+        """
+        for param in (model_id, model_alias):
+            if param in SKIP_IN_PATH:
+                raise ValueError("Empty value passed for a required argument.")
+
+        return self.transport.perform_request(
+            "DELETE",
+            _make_path("_ml", "trained_models", model_id, "model_aliases", model_alias),
+            params=params,
+            headers=headers,
+        )
+
+    @query_params()
+    def preview_data_frame_analytics(
+        self, body=None, id=None, params=None, headers=None
+    ):
+        """
+        Previews that will be analyzed given a data frame analytics config.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/preview-dfanalytics.html>`_
+
+        :arg body: The data frame analytics config to preview
+        :arg id: The ID of the data frame analytics to preview
+        """
+        return self.transport.perform_request(
+            "POST",
+            _make_path("_ml", "data_frame", "analytics", id, "_preview"),
+            params=params,
+            headers=headers,
+            body=body,
+        )
+
+    @query_params("reassign")
+    def put_trained_model_alias(self, model_id, model_alias, params=None, headers=None):
+        """
+        Creates a new model alias (or reassigns an existing one) to refer to the
+        trained model
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/put-trained-models-aliases.html>`_
+
+        :arg model_id: The trained model where the model alias should be
+            assigned
+        :arg model_alias: The trained model alias to update
+        :arg reassign: If the model_alias already exists and points to a
+            separate model_id, this parameter must be true. Defaults to false.
+        """
+        for param in (model_id, model_alias):
+            if param in SKIP_IN_PATH:
+                raise ValueError("Empty value passed for a required argument.")
+
+        return self.transport.perform_request(
+            "PUT",
+            _make_path("_ml", "trained_models", model_id, "model_aliases", model_alias),
+            params=params,
+            headers=headers,
+        )
+
     @query_params(
         "charset",
         "column_names",
@@ -1682,7 +1684,7 @@ class MlClient(NamespacedClient):
         Finds the structure of a text file. The text file must contain data that is
         suitable to be ingested into Elasticsearch.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/find-structure.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/find-structure.html>`_
 
         .. warning::
 
