@@ -24,7 +24,7 @@ class SnapshotClient(NamespacedClient):
         """
         Creates a snapshot in a repository.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg snapshot: A snapshot name
@@ -51,7 +51,7 @@ class SnapshotClient(NamespacedClient):
         """
         Deletes a snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg snapshot: A snapshot name
@@ -69,18 +69,20 @@ class SnapshotClient(NamespacedClient):
             headers=headers,
         )
 
-    @query_params("ignore_unavailable", "master_timeout", "verbose")
+    @query_params("ignore_unavailable", "index_details", "master_timeout", "verbose")
     def get(self, repository, snapshot, params=None, headers=None):
         """
         Returns information about a snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg snapshot: A comma-separated list of snapshot names
         :arg ignore_unavailable: Whether to ignore unavailable
             snapshots, defaults to false which means a SnapshotMissingException is
             thrown
+        :arg index_details: Whether to include details of each index in
+            the snapshot, if those details are available. Defaults to false.
         :arg master_timeout: Explicit operation timeout for connection
             to master node
         :arg verbose: Whether to show verbose snapshot info or only show
@@ -102,7 +104,7 @@ class SnapshotClient(NamespacedClient):
         """
         Deletes a repository.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-snapshots.html>`_
 
         :arg repository: Name of the snapshot repository to unregister.
             Wildcard (`*`) patterns are supported.
@@ -125,7 +127,7 @@ class SnapshotClient(NamespacedClient):
         """
         Returns information about a repository.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-snapshots.html>`_
 
         :arg repository: A comma-separated list of repository names
         :arg local: Return local information, do not retrieve the state
@@ -142,7 +144,7 @@ class SnapshotClient(NamespacedClient):
         """
         Creates a repository.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg body: The repository definition
@@ -168,7 +170,7 @@ class SnapshotClient(NamespacedClient):
         """
         Restores a snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg snapshot: A snapshot name
@@ -195,7 +197,7 @@ class SnapshotClient(NamespacedClient):
         """
         Returns information about the status of a snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg snapshot: A comma-separated list of snapshot names
@@ -217,7 +219,7 @@ class SnapshotClient(NamespacedClient):
         """
         Verifies a repository.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg master_timeout: Explicit operation timeout for connection
@@ -239,7 +241,7 @@ class SnapshotClient(NamespacedClient):
         """
         Removes stale data from repository.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/clean-up-snapshot-repo-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/clean-up-snapshot-repo-api.html>`_
 
         :arg repository: A repository name
         :arg master_timeout: Explicit operation timeout for connection
@@ -263,7 +265,7 @@ class SnapshotClient(NamespacedClient):
         """
         Clones indices from one snapshot into another snapshot in the same repository.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg snapshot: The name of the snapshot to clone from
